==> com.liferay.frontend.js.loader.modules.extender-1.0.15-sources-commercial.jar: com/liferay/frontend/js/loader/modules/extender/internal/npm/flat/FlatJSModule.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.js.loader.modules.extender.internal.npm.flat;

import com.liferay.frontend.js.loader.modules.extender.npm.JSPackage;
import com.liferay.frontend.js.loader.modules.extender.npm.ModuleNameUtil;
import com.liferay.frontend.js.loader.modules.extender.npm.builtin.BuiltInJSModule;

import java.io.IOException;
import java.io.InputStream;

import java.net.URL;

import java.util.Collection;

/**
 * Provides a complete implementation of {@link
 * com.liferay.frontend.js.loader.modules.extender.npm.JSModule}.
 *
 * @author Iván Zaera
 */
public class FlatJSModule extends BuiltInJSModule {

	/**
	 * Constructs a <code>FlatJSModule</code> with the module's package, name,
	 * and dependencies.
	 *
	 * @param jsPackage the module's package
	 * @param name the module's name
	 * @param dependencies the module names this module depends on
	 */
	public FlatJSModule(
		JSPackage jsPackage, String name, Collection<String> dependencies) {

		super(jsPackage, name, dependencies);

		_resource = jsPackage.getResourceURL(
			ModuleNameUtil.toFileName(getName()));
	}

	@Override
	public InputStream getInputStream() throws IOException {
		return _resource.openStream();
	}

	@Override
	public String toString() {
		return getId();
	}

	private final URL _resource;

}

==> com.liferay.frontend.js.loader.modules.extender-3.0.3-sources-commercial.jar: com/liferay/frontend/js/loader/modules/extender/internal/npm/flat/FlatJSModule.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.js.loader.modules.extender.internal.npm.flat;

import com.liferay.frontend.js.loader.modules.extender.npm.JSPackage;
import com.liferay.frontend.js.loader.modules.extender.npm.ModuleNameUtil;
import com.liferay.frontend.js.loader.modules.extender.npm.builtin.BuiltInJSModule;

import java.io.IOException;
import java.io.InputStream;

import java.net.URL;

import java.util.Collection;

/**
 * Provides a complete implementation of {@link
 * com.liferay.frontend.js.loader.modules.extender.npm.JSModule}.
 *
 * @author Iván Zaera
 */
public class FlatJSModule extends BuiltInJSModule {

	/**
	 * Constructs a <code>FlatJSModule</code> with the module's package, name,
	 * and dependencies.
	 *
	 * @param jsPackage the module's package
	 * @param name the module's name
	 * @param dependencies the module names this module depends on
	 */
	public FlatJSModule(
		JSPackage jsPackage, String name, Collection<String> dependencies) {

		super(jsPackage, name, dependencies);

		String fileName = ModuleNameUtil.toFileName(getName());

		_jsURL = jsPackage.getResourceURL(fileName);
		_sourceMapURL = jsPackage.getResourceURL(fileName + ".map");
	}

	@Override
	public InputStream getInputStream() throws IOException {
		return _jsURL.openStream();
	}

	@Override
	public InputStream getSourceMapInputStream() throws IOException {
		return _sourceMapURL.openStream();
	}

	@Override
	public String toString() {
		return getId();
	}

	private final URL _jsURL;
	private final URL _sourceMapURL;

}
